==> dotnet6_6.0.136.orig.tar.xz: src/roslyn/src/Workspaces/Core/Portable/Shared/TestHooks/FeatureAttribute.cs <==
﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
// See the LICENSE file in the project root for more information.

namespace Microsoft.CodeAnalysis.Shared.TestHooks
{
    internal static class FeatureAttribute
    {
        public const string AutomaticEndConstructCorrection = nameof(AutomaticEndConstructCorrection);
        public const string AutomaticPairCompletion = nameof(AutomaticPairCompletion);
        public const string BraceHighlighting = nameof(BraceHighlighting);
        public const string CallHierarchy = nameof(CallHierarchy);
        public const string Classification = nameof(Classification);
        public const string CodeModel = nameof(CodeModel);
        public const string CompletionSet = nameof(CompletionSet);
        public const string DesignerAttributes = nameof(DesignerAttributes);
        public const string DiagnosticService = nameof(DiagnosticService);
        public const string EncapsulateField = nameof(EncapsulateField);
        public const string ErrorList = nameof(ErrorList);
        public const string ErrorSquiggles = nameof(ErrorSquiggles);
        public const string EventHookup = nameof(EventHookup);
        public const string FindReferences = nameof(FindReferences);
        public const string GlobalOperation = nameof(GlobalOperation);
        public const string GoToImplementation = nameof(GoToImplementation);
        public const string GraphProvider = nameof(GraphProvider);
        public const string InfoBar = nameof(InfoBar);
        public const string InheritanceMargin = nameof(InheritanceMargin);
        public const string InlineHints = nameof(InlineHints);
        public const string InteractiveEvaluator = nameof(InteractiveEvaluator);
        public const string KeywordHighlighting = nameof(KeywordHighlighting);
        public const string LibraryManager = nameof(LibraryManager);
        public const string LightBulb = nameof(LightBulb);
        public const string LineSeparators = nameof(LineSeparators);
        public const string NavigableSymbols = nameof(NavigableSymbols);
        public const string NavigateTo = nameof(NavigateTo);
        public const string NavigationBar = nameof(NavigationBar);
        public const string Outlining = nameof(Outlining);
        public const string PackageInstaller = nameof(PackageInstaller);
        public const string PersistentStorage = nameof(PersistentStorage);
        public const string QuickInfo = nameof(QuickInfo);
        public const string ReferenceHighlighting = nameof(ReferenceHighlighting);
        public const string Rename = nameof(Rename);
        public const string RenameTracking = nameof(RenameTracking);
        public const string SolutionChecksumUpdater = nameof(SolutionChecksumUpdater);
        public const string SourceGenerators = nameof(SourceGenerators);
        public const string RuleSetEditor = nameof(RuleSetEditor);
        public const string SignatureHelp = nameof(SignatureHelp);
        public const string Snippets = nameof(Snippets);
        public const string SolutionCrawler = nameof(SolutionCrawler);
        public const string Telemetry = nameof(Telemetry);
        public const string TodoCommentList = nameof(TodoCommentList);
        public const string LanguageServer = nameof(LanguageServer);
        public const string Workspace = nameof(Workspace);
    }
}

==> dotnet8_8.0.123-8.0.23.orig.tar.xz: src/roslyn/src/Workspaces/Core/Portable/Shared/TestHooks/FeatureAttribute.cs <==
﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
// See the LICENSE file in the project root for more information.

namespace Microsoft.CodeAnalysis.Shared.TestHooks
{
    internal static class FeatureAttribute
    {
        public const string AddImportsOnPaste = nameof(AddImportsOnPaste);
        public const string AutomaticEndConstructCorrection = nameof(AutomaticEndConstructCorrection);
        public const string AutomaticPairCompletion = nameof(AutomaticPairCompletion);
        public const string BraceHighlighting = nameof(BraceHighlighting);
        public const string BracePairs = nameof(BracePairs);
        public const string CallHierarchy = nameof(CallHierarchy);
        public const string Classification = nameof(Classification);
        public const string CodeDefinitionWindow = nameof(CodeDefinitionWindow);
        public const string CodeLens = nameof(CodeLens);
        public const string CodeModel = nameof(CodeModel);
        public const string CompletionSet = nameof(CompletionSet);
        public const string DesignerAttributes = nameof(DesignerAttributes);
        public const string DiagnosticService = nameof(DiagnosticService);
        public const string DocumentOutline = nameof(DocumentOutline);
        public const string EditAndContinue = nameof(EditAndContinue);
        public const string EncapsulateField = nameof(EncapsulateField);
        public const string ErrorList = nameof(ErrorList);
        public const string ErrorSquiggles = nameof(ErrorSquiggles);
        public const string EventHookup = nameof(EventHookup);
        public const string ExtractMethod = nameof(ExtractMethod);
        public const string FindReferences = nameof(FindReferences);
        public const string GlobalOperation = nameof(GlobalOperation);
        public const string GoToBase = nameof(GoToBase);
        public const string GoToDefinition = nameof(GoToDefinition);
        public const string GoToImplementation = nameof(GoToImplementation);
        public const string GraphProvider = nameof(GraphProvider);
        public const string InfoBar = nameof(InfoBar);
        public const string InheritanceMargin = nameof(InheritanceMargin);
        public const string InlineDiagnostics = nameof(InlineDiagnostics);
        public const string InlineHints = nameof(InlineHints);
        public const string InlineRenameFlyout = nameof(InlineRenameFlyout);
        public const string InteractiveEvaluator = nameof(InteractiveEvaluator);
        public const string KeywordHighlighting = nameof(KeywordHighlighting);
        public const string LanguageServer = nameof(LanguageServer);
        public const string LibraryManager = nameof(LibraryManager);
        public const string LightBulb = nameof(LightBulb);
        public const string LineSeparators = nameof(LineSeparators);
        public const string NavigableSymbols = nameof(NavigableSymbols);
        public const string NavigateTo = nameof(NavigateTo);
        public const string NavigationBar = nameof(NavigationBar);
        public const string Outlining = nameof(Outlining);
        public const string OrganizeDocument = nameof(OrganizeDocument);
        public const string PackageInstaller = nameof(PackageInstaller);
        public const string PersistentStorage = nameof(PersistentStorage);
        public const string QuickInfo = nameof(QuickInfo);
        public const string ReferenceHighlighting = nameof(ReferenceHighlighting);
        public const string Rename = nameof(Rename);
        public const string RenameTracking = nameof(RenameTracking);
        public const string RuleSetEditor = nameof(RuleSetEditor);
        public const string SignatureHelp = nameof(SignatureHelp);
        public const string Snippets = nameof(Snippets);
        public const string SolutionChecksumUpdater = nameof(SolutionChecksumUpdater);
        public const string SolutionCrawlerLegacy = nameof(SolutionCrawlerLegacy);
        public const string SolutionCrawlerUnitTesting = nameof(SolutionCrawlerUnitTesting);
        public const string SourceGenerators = nameof(SourceGenerators);
        public const string StringIndentation = nameof(StringIndentation);
        public const string TaskList = nameof(TaskList);
        public const string Telemetry = nameof(Telemetry);
        public const string ValueTracking = nameof(ValueTracking);
        public const string Workspace = nameof(Workspace);
    }
}
